@@ -1,5 +1,6 @@
 import types as t
 import os, imp
+import inspect
 
 def scan_folder_recurse(folder, excl_names=['__']):
     """ Recurse search for PY files in given folder """                                                                                                                                   
@@ -13,9 +14,9 @@ def scan_folder_recurse(folder, excl_names=['__']):
 def scan_package(p):
     for x in dir(p):
         if not x.startswith("_"):
-            o = getattr(p, x)        
-            if   type(o) == t.ClassType:
-                yield o
+            o = getattr(p, x)
+            if inspect.isclass(o) and o.__module__.startswith(p.__name__) and getattr(o, "METAROUTE_CONTROLLER_PATH", None) is not None: 
+                    yield o
 
 def attach_controllers(app, pkg):
     pkg_path  = pkg.__path__[0]
@@ -46,7 +47,6 @@ def attach_controller(app, mdl):
                         xf = cls.__dict__[m.__name__].__get__(ctrl, cls)
                         opts['endpoint'] = cls.__module__ + "." + cls.__name__ + "." + xf.__name__
                         app.route(cpath + path, **opts)(cls.__dict__[m.__name__].__get__(ctrl, cls))
-                        print "Enhanced [%s]" % meth
     
                     for ex in getattr(m, "METAROUTE_ERROR_EXCEPTIONS", []):
                         app._register_error_handler(None, ex, cls.__dict__[m.__name__].__get__(ctrl, cls))
